@@ -22,11 +22,16 @@
 #'    indicar diferentes coordenadas possíveis (e.g. duas ruas diferentes com o
 #'    mesmo nome em uma mesma cidade). Esses casos são trados como 'empate' e o
 #'    parâmetro `resolver_empates` indica se a função deve resolver esses empates
-#'    automaticamente. Por padrão, é `FALSE`, e a função retorna apenas o caso
+#'    automaticamente. Por padrão, é `TRUE`, e a função retorna apenas o caso
 #'    mais provável. Para mais detalhes sobre como é feito o processo de
 #'    desempate, consulte abaixo a seção "Detalhes".
-#' @template h3_res
 #' @template resultado_sf
+#' @template h3_res
+#' @param padronizar_enderecos Lógico. Indica se os dados de endereço de entrada
+#'    devem ser padronizados. Por padrão, é `TRUE`. Essa padronização é essencial
+#'    para uma geolocalizaçao correta. Alerta! Apenas utilize
+#'    `padronizar_enderecos = FALSE` caso os dados de input já tenham sido
+#'    padronizados anteriormente com `enderecobr::padronizar_enderecos(..., formato_estados = 'sigla', formato_numeros = 'integer')`.
 #' @template verboso
 #' @template cache
 #' @template n_cores
@@ -58,8 +63,7 @@
 #' df <- geocodebr::geocode(
 #'   enderecos = input_df,
 #'   campos_endereco = fields,
-#'   resolver_empates = TRUE,
-#'   verboso = FALSE
+#'   resolver_empates = TRUE
 #'   )
 #'
 #' head(df)
@@ -68,12 +72,73 @@
 geocode <- function(enderecos,
                     campos_endereco = definir_campos(),
                     resultado_completo = FALSE,
-                    resolver_empates = FALSE,
-                    h3_res = NULL,
+                    resolver_empates = TRUE,
                     resultado_sf = FALSE,
+                    h3_res = NULL,
+                    padronizar_enderecos = TRUE,
                     verboso = TRUE,
                     cache = TRUE,
-                    n_cores = 1 ){
+                    n_cores = NULL ){
+
+  callr::r(
+    func = function(enderecos,
+                    campos_endereco,
+                    resultado_completo,
+                    resolver_empates,
+                    resultado_sf,
+                    h3_res,
+                    padronizar_enderecos,
+                    verboso,
+                    cache,
+                    n_cores) {
+
+      # Run internal engine
+      geocode_core(
+        enderecos = enderecos,
+        campos_endereco = campos_endereco,
+        resultado_completo = resultado_completo,
+        resolver_empates = resolver_empates,
+        resultado_sf = resultado_sf,
+        h3_res = h3_res,
+        padronizar_enderecos = padronizar_enderecos,
+        verboso =verboso,
+        cache = cache,
+        n_cores = n_cores
+      )
+
+    },
+    args = list(
+      enderecos = enderecos,
+      campos_endereco = campos_endereco,
+      resultado_completo = resultado_completo,
+      resolver_empates = resolver_empates,
+      resultado_sf = resultado_sf,
+      h3_res = h3_res,
+      padronizar_enderecos = padronizar_enderecos,
+      verboso =verboso,
+      cache = cache,
+      n_cores = n_cores
+    ),
+    show = TRUE,
+    package = TRUE
+
+  )
+
+}
+
+
+
+#' @keywords internal
+geocode_core <- function(enderecos = parent.frame()$enderecos,
+                         campos_endereco = parent.frame()$campos_endereco,
+                         resultado_completo = parent.frame()$resultado_completo,
+                         resolver_empates = parent.frame()$resolver_empates,
+                         resultado_sf = parent.frame()$resultado_sf,
+                         h3_res = parent.frame()$h3_res,
+                         padronizar_enderecos = parent.frame()$padronizar_enderecos,
+                         verboso = parent.frame()$verboso,
+                         cache = parent.frame()$cache,
+                         n_cores = parent.frame()$n_cores){
 
 
   # ## ---- tiny timing toolkit (self-contained) ------------------------------
@@ -130,39 +195,55 @@ geocode <- function(enderecos,
   checkmate::assert_logical(resultado_completo, any.missing = FALSE, len = 1)
   checkmate::assert_logical(resolver_empates, any.missing = FALSE, len = 1)
   checkmate::assert_logical(resultado_sf, any.missing = FALSE, len = 1)
+  checkmate::assert_logical(padronizar_enderecos, any.missing = FALSE, len = 1)
   checkmate::assert_logical(verboso, any.missing = FALSE, len = 1)
   checkmate::assert_logical(cache, any.missing = FALSE, len = 1)
-  checkmate::assert_number(n_cores, lower = 1, finite = TRUE)
   checkmate::assert_numeric(h3_res, null.ok = TRUE, lower = 0, upper = 15, max.len = 16)
-  campos_endereco <- assert_and_assign_address_fields(
-    campos_endereco,
-    enderecos
-  )
+
+
+      # systime start 66666 ----------------
+      # timer$mark("Start")
+
 
   # normalize input data -------------------------------------------------------
-
   # standardizing the addresses table to increase the chances of finding a match
   # in the CNEFE data
 
-  if (verboso) message_standardizing_addresses()
+    if (isTRUE(padronizar_enderecos)) {
 
-  # systime start 66666 ----------------
-  # timer$mark("Start")
+      if (verboso) message_standardizing_addresses()
 
+      campos_endereco <- assert_and_assign_address_fields(
+        campos_endereco,
+        enderecos
+      )
+
+      input_padrao <- enderecobr::padronizar_enderecos(
+        enderecos = enderecos,
+        campos_do_endereco = enderecobr::correspondencia_campos(
+          logradouro = campos_endereco[["logradouro"]],
+          numero = campos_endereco[["numero"]],
+          cep = campos_endereco[["cep"]],
+          bairro = campos_endereco[["localidade"]],
+          municipio = campos_endereco[["municipio"]],
+          estado = campos_endereco[["estado"]]
+        ),
+        formato_estados = "sigla",
+        formato_numeros = 'integer'
+      )
+
+    }
+
+  if (isFALSE(padronizar_enderecos)) {
+    input_padrao <- data.table::copy(enderecos)
+  }
+
+  # checa se input foi mesmo padronizado
+  all_cols_padr <- c("estado_padr", "municipio_padr", "logradouro_padr", "numero_padr", "cep_padr", "bairro_padr")
+  check_padr <- all(all_cols_padr %in% names(input_padrao))
+
+  if (isFALSE(check_padr)) { error_input_nao_padronizado() }
 
-  input_padrao <- enderecobr::padronizar_enderecos(
-    enderecos,
-    campos_do_endereco = enderecobr::correspondencia_campos(
-      logradouro = campos_endereco[["logradouro"]],
-      numero = campos_endereco[["numero"]],
-      cep = campos_endereco[["cep"]],
-      bairro = campos_endereco[["localidade"]],
-      municipio = campos_endereco[["municipio"]],
-      estado = campos_endereco[["estado"]]
-    ),
-    formato_estados = "sigla",
-    formato_numeros = 'integer'
-  )
 
 
   # keep and rename colunms of input_padrao to use the
@@ -217,10 +298,6 @@ geocode <- function(enderecos,
   # issue https://github.com/ipeaGIT/geocodebr/issues/67
   cria_col_logradouro_confusao(con)
 
-  # systime cria coluna "log_causa_confusao 66666 ----------------
-  # timer$mark("Cria coluna log_causa_confusao")
-
-
 
 
   # create an empty output table that will be populated -----------------------------------------------
@@ -267,6 +344,8 @@ geocode <- function(enderecos,
                          overwrite = TRUE, temporary = TRUE)
 
 
+
+
   # START MATCHING -----------------------------------------------
 
   # start progress bar
@@ -330,7 +409,7 @@ geocode <- function(enderecos,
     resultado_completo,
     resolver_empates,
     verboso
-    )
+  )
 
 
 
@@ -378,18 +457,8 @@ geocode <- function(enderecos,
 
 
 
-
-
-
-  # systime merge results 66666 ----------------
-  # timer$mark("Merge results")
-
-
   data.table::setDT(output_df)
 
-  # systime resolve empates 66666 ----------------
-  # timer$mark("Resolve empates")
-
 
   # drop geocodebr temp id column
   output_df[, tempidgeocodebr := NULL]
@@ -399,8 +468,6 @@ geocode <- function(enderecos,
   duckdb::dbDisconnect(con)
 
 
-  # add H3
-
   # add H3
   if (!is.null(h3_res)) {
 
@@ -421,6 +488,9 @@ geocode <- function(enderecos,
 
   }
 
+  # remove data.table class
+  data.table::setindex(output_df, NULL)
+  data.table::setDF(output_df)
 
   # convert df to simple feature
   if (isTRUE(resultado_sf)) {
