@@ -11,31 +11,12 @@ match_cases <- function( # nocov start
   # get corresponding parquet table
   cnefe_table_name <- get_reference_table(match_type)
   y <- cnefe_table_name
+  key_cols <- get_key_cols(match_type)
 
-  # build path to local file
-  path_to_parquet <- fs::path(
-    listar_pasta_cache(),
-    glue::glue("geocodebr_data_release_{data_release}"),
-    paste0(cnefe_table_name,".parquet")
-  )
+  # write cnefe table to db
+  register_cnefe_table(con, match_type)
 
-  # determine geographical scope of the search
-  input_states <- DBI::dbGetQuery(con, "SELECT DISTINCT estado FROM input_padrao_db;")$estado
-  input_municipio <- DBI::dbGetQuery(con, "SELECT DISTINCT municipio FROM input_padrao_db;")$municipio
 
-  # Load CNEFE data and write to DuckDB
-  # filter cnefe to include only states and municipalities
-  # present in the input table, reducing the search scope
-  filtered_cnefe <- arrow_open_dataset( path_to_parquet ) |>
-    dplyr::filter(estado %in% input_states) |>
-    dplyr::filter(municipio %in% input_municipio) |>
-    dplyr::compute()
-
-  # c <- collect(filtered_cnefe)
-  # summary(c$desvio_metros)
-
-  # register filtered_cnefe to db
-  duckdb::duckdb_register_arrow(con, cnefe_table_name, filtered_cnefe)
 
   # Create the JOIN condition by concatenating the key columns
   join_condition <- paste(
@@ -90,13 +71,11 @@ match_cases <- function( # nocov start
       WHERE {cols_not_null} AND {y}.lon IS NOT NULL;"
   )
 
-  DBI::dbSendQueryArrow(con, query_match)
+  DBI::dbExecute(con, query_match)
   # a <- DBI::dbReadTable(con, 'output_db')
   # summary(a$desvio_metros)
   # summary(a$lat)
 
-  #### 66666 remover
-  duckdb::duckdb_unregister_arrow(con, cnefe_table_name)
 
   # UPDATE input_padrao_db: Remove observations found in previous step
   temp_n <- update_input_db(
