@@ -7,7 +7,7 @@ testthat::skip_if_not_installed("arrow")
 data_path <- system.file("extdata/small_sample.csv", package = "geocodebr")
 input_df <- read.csv(data_path)
 
-campos <- definir_campos(
+campos <- geocodebr::definir_campos(
   logradouro = "nm_logradouro",
   numero = "Numero",
   cep = "Cep",
@@ -20,8 +20,9 @@ tester <- function(enderecos = input_df,
                    campos_endereco = campos,
                    resultado_completo = FALSE,
                    resolver_empates = FALSE,
-                   h3_res = NULL,
                    resultado_sf = FALSE,
+                   h3_res = NULL,
+                   padronizar_enderecos = TRUE,
                    verboso = FALSE,
                    cache = TRUE,
                    n_cores = 1) {
@@ -30,8 +31,9 @@ tester <- function(enderecos = input_df,
     campos_endereco,
     resultado_completo,
     resolver_empates,
-    h3_res,
     resultado_sf,
+    h3_res,
+    padronizar_enderecos,
     verboso,
     cache,
     n_cores
@@ -40,14 +42,15 @@ tester <- function(enderecos = input_df,
 
 test_that("expected output", {
 
-  testthat::expect_warning(std_output <- tester())
+  std_output <- tester()
 
   # find expected match cases
   match_types_found <- unique(std_output$tipo_resultado)
   testthat::expect_true(length(match_types_found) == 17)
 
   # full results
-  testthat::expect_warning(full_output <- tester(resultado_completo = TRUE))
+  full_output <- tester(resultado_completo = TRUE)
+
 
   all_cols_completas <- c("lat", "lon", "precisao", "tipo_resultado",
     "desvio_metros", "endereco_encontrado", "logradouro_encontrado",
@@ -62,19 +65,48 @@ test_that("expected output", {
   testthat::expect_true(all(c('h3_03', 'h3_04') %in% names(std_output_h3)))
 
   # output in sf format
-  testthat::expect_warning(sf_output <- tester(resultado_sf = TRUE))
+  sf_output <- tester(resultado_sf = TRUE)
   testthat::expect_true(is(sf_output , 'sf'))
 })
 
 
+test_that("argumento padronizar endereco", {
+
+  # erro se input nao estiver padronizado
+  testthat::expect_error( tester(padronizar_enderecos = FALSE) )
+
+  # sucesso se tiver sido padronizado
+  campos2 <- enderecobr::correspondencia_campos(
+    logradouro = "nm_logradouro",
+    numero = "Numero",
+    cep = "Cep",
+    bairro = "Bairro",
+    municipio = "nm_municipio",
+    estado = "nm_uf"
+  )
+
+  input_padr <- enderecobr::padronizar_enderecos(
+    enderecos = input_df,
+    campos_do_endereco = campos2,
+    formato_estados = "sigla",
+    formato_numeros = 'integer'
+    )
+
+  testthat::succeed(
+    tester(enderecos = input_padr, padronizar_enderecos = FALSE)
+  )
+
+})
+
+
 test_that("test empates", {
 
   # com empates
-  testthat::expect_warning( std_output <- tester(resolver_empates = FALSE) )
+  std_output <- tester(resolver_empates = FALSE)
   testthat::expect_true(nrow(std_output) > nrow(input_df))
 
   # resolvendo empates
-  testthat::expect_message( std_output <- tester(verboso = TRUE, resolver_empates = TRUE) )
+  std_output <- tester(verboso = TRUE, resolver_empates = TRUE)
   testthat::expect_true(nrow(std_output) == nrow(input_df))
 
   # output ordenado como input
@@ -85,18 +117,19 @@ test_that("test empates", {
   testthat::expect_true('h3_03' %in% names(std_output_h3))
 })
 
-test_that("test no messages", {
-
-  testthat::expect_no_message(
-    testthat::expect_warning(
-      std_output <- tester(verboso = FALSE,
-                           resolver_empates = FALSE)
-                               ))
-
-  testthat::expect_no_message( std_output <- tester(verboso = FALSE,
-                                                    resolver_empates = TRUE)
-                             )
-})
+# test_that("test no messages", {
+#
+#   testthat::expect_no_message(
+#     testthat::expect_warning(
+#       std_output <- tester(verboso = FALSE,
+#                            resolver_empates = FALSE)
+#                                )
+#     )
+#
+#    testthat::expect_no_message(
+#     std_output <- tester(verboso = FALSE, resolver_empates = TRUE)
+#                             )
+# })
 
 
 test_that("errors with incorrect input", {
@@ -118,6 +151,10 @@ test_that("errors with incorrect input", {
   expect_error(tester(resultado_sf = NA))
   expect_error(tester(resultado_sf = c(TRUE, TRUE)))
 
+  expect_error(tester(padronizar_enderecos = "a"))
+  expect_error(tester(padronizar_enderecos = 50))
+  expect_error(tester(padronizar_enderecos = Inf))
+
   expect_error(tester(h3_res = "a"))
   expect_error(tester(h3_res = 50))
   expect_error(tester(h3_res = Inf))
